:class:`RepeatedExperiment`: Repeating an experiment experiment
===============================================================

.. currentmodule:: epyc
   
.. autoclass:: RepeatedExperiment


Perforing repetitions
----------------------

.. automethod:: RepeatedExperiment.__init__

.. automethod:: RepeatedExperiment.repetitions

		
Running the experiment
----------------------

.. automethod:: RepeatedExperiment.do

.. automethod:: RepeatedExperiment.report
